==> MoinLight-0.1.tar.bz2: MoinLight-0.1/moinformat/serialisers/moin/moin.py <==
#!/usr/bin/env python

"""
Moin wiki text serialiser.

Copyright (C) 2017, 2018 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.serialisers.common import escape_attr, escape_text, Serialiser

class MoinSerialiser(Serialiser):

    "Serialisation of the page."

    format = "moin"

    def start_region(self, level, indent, type, extra):
        out = self.out
        if level:
            out(" " * indent + "{" * level)

        # Produce a header for regions within a top-level region.

        if type and type != "inline" and level:
            out("#!%s\n" % type)

    def end_region(self, level, indent, type, extra):
        out = self.out
        if level:
            out("%s%s" % ("}" * level, extra or ""))

    def start_block(self):
        pass

    def end_block(self):
        pass

    def start_defitem(self, pad, extra):
        self.out((extra and extra + "::" or "") + pad)

    def end_defitem(self, pad, extra):
        pass

    def start_defterm(self, pad, extra):
        self.out(pad)

    def end_defterm(self, pad, extra):
        self.out("::" + extra)

    def start_emphasis(self):
        self.out("''")

    def end_emphasis(self):
        self.out("''")

    def start_heading(self, level, extra, pad, identifier):
        self.out(extra + "=" * level + pad)

    def end_heading(self, level, pad, extra):
        self.out(pad + "=" * level + extra)

    def start_larger(self):
        self.out("~+")

    def end_larger(self):
        self.out("+~")

    def start_list(self, indent, marker, num):
        pass

    def end_list(self, indent, marker, num):
        pass

    def start_listitem(self, indent, marker, space, num):
        self.out("%s%s%s%s" % (indent * " ", marker, num and "#%s" % num or "", space))

    def end_listitem(self, indent, marker, space, num):
        pass

    def start_macro(self, name, args, nodes, inline):

        # Fallback case for when macros are not replaced.

        if not nodes:
            self.out("<<%s%s>>" % (name, args and "(%s)" % ",".join(args) or ""))

    def end_macro(self, inline):
        pass

    def start_monospace(self):
        self.out("`")

    def end_monospace(self):
        self.out("`")

    def start_smaller(self):
        self.out("~-")

    def end_smaller(self):
        self.out("-~")

    def start_strong(self):
        self.out("'''")

    def end_strong(self):
        self.out("'''")

    def start_strikethrough(self):
        self.out("--(")

    def end_strikethrough(self):
        self.out(")--")

    def start_subscript(self):
        self.out(",,")

    def end_subscript(self):
        self.out(",,")

    def start_superscript(self):
        self.out("^")

    def end_superscript(self):
        self.out("^")

    def start_table(self):
        pass

    def end_table(self):
        pass

    def start_table_attrs(self):
        self.out("<")

    def end_table_attrs(self):
        self.out(">")

    def start_table_cell(self, attrs):
        self.out("||")

    def end_table_cell(self):
        pass

    def start_table_row(self):
        pass

    def end_table_row(self, trailing):
        self.out("||")
        self.out(trailing)

    def start_underline(self):
        self.out("__")

    def end_underline(self):
        self.out("__")

    def anchor(self, target):
        self.out("((%s))" % target)

    def break_(self):
        self.out("\n")

    def comment(self, comment, extra):
        self.out("##%s%s" % (comment, extra))

    def directive(self, directive, extra):
        self.out("#%s%s" % (directive, extra))

    def linebreak(self):
        self.out(r"\\")

    def link(self, target, nodes):
        self.out("[[%s" % target)
        for node in nodes:
            self.out("|")
            node.to_string(self)
        self.out("]]")

    def link_label(self, nodes):
        for node in nodes:
            node.to_string(self)

    def link_parameter(self, key_value):
        if len(key_value) == 1:
            self.out(key_value[0])
        else:
            self.out("=".join(key_value))

    def rule(self, height):
        self.out("-" * (height + 4))

    def table_attrs(self, nodes):
        for node in nodes:
            node.to_string(self)

    def table_attr(self, name, value, concise, quote):
        if concise:
            if name == "bgcolor": self.out(value)
            elif name == "colspan": self.out("-%s" % value)
            elif name == "align" : self.out(value == "left" and "(" or value == "right" and ")" or ":")
            elif name == "rowspan": self.out("|%s" % value)
            elif name == "valign" : self.out(value == "top" and "^" or "v")
            elif name == "width" : self.out(value)
        else:
            self.out("%s%s" % (escape_text(name), value is not None and
                               "=%s%s%s" % (quote or '"', escape_attr(value), quote or '"') or ""))

    def text(self, s):
        self.out(s)

    def transclusion(self, target, nodes):
        self.out("{{%s" % target)
        for node in nodes:
            self.out("|")
            node.to_string(self)
        self.out("}}")

    def verbatim(self, text):
        self.out("<<<")
        self.out(text)
        self.out(">>>")

serialiser = MoinSerialiser

# vim: tabstop=4 expandtab shiftwidth=4

==> MoinLight-0.2.1.tar.bz2: MoinLight-0.2.1/moinformat/serialisers/moin/moin.py <==
#!/usr/bin/env python

"""
Moin wiki text serialiser.

Copyright (C) 2017, 2018, 2021, 2022 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.serialisers.common import escape_attr, escape_text, Serialiser

class MoinSerialiser(Serialiser):

    "Serialisation of the page."

    input_formats = ["moin", "wiki"]
    formats = ["moin", "wiki"]

    def start_region(self, level, indent, type, args, extra):
        out = self.out
        if level:
            out(" " * indent + "{" * level)

        # Produce a header for regions within a top-level region.

        if type and type != "inline" and level:

            # Obtain individual arguments, excluding the region type.

            args = args.split(" ")[1:]
            args_str = args and (" %s" % " ".join(args)) or ""

            out("#!%s%s\n" % (type, args_str))

    def end_region(self, level, indent, type, args, extra):
        out = self.out
        if level:
            out("%s%s" % ("}" * level, extra or ""))

    def start_block(self):
        pass

    def end_block(self):
        pass

    def start_defitem(self, pad, extra):
        self.out((extra and extra + "::" or "") + pad)

    def end_defitem(self, pad, extra):
        pass

    def start_defterm(self, pad, extra):
        self.out(pad)

    def end_defterm(self, pad, extra):
        self.out("::" + extra)

    def start_emphasis(self):
        self.out("''")

    def end_emphasis(self):
        self.out("''")

    def start_heading(self, level, extra, pad, identifier):
        self.out(extra + "=" * level + pad)

    def end_heading(self, level, pad, extra):
        self.out(pad + "=" * level + extra)

    def start_larger(self):
        self.out("~+")

    def end_larger(self):
        self.out("+~")

    def start_list(self, indent, marker, num):
        pass

    def end_list(self, indent, marker, num):
        pass

    def start_listitem(self, indent, marker, space, num):
        self.out("%s%s%s%s" % (indent * " ", marker, num and "#%s" % num or "", space))

    def end_listitem(self, indent, marker, space, num):
        pass

    def start_macro(self, name, args, nodes, inline):

        # Special case of a deliberately unexpanded macro.

        if nodes is None:
            return

        # Fallback case for when macros are not replaced.

        if not nodes:
            self.out("<<%s%s>>" % (name, args and "(%s)" % ",".join(args) or ""))

    def end_macro(self, inline):
        pass

    def start_monospace(self):
        self.out("`")

    def end_monospace(self):
        self.out("`")

    def start_smaller(self):
        self.out("~-")

    def end_smaller(self):
        self.out("-~")

    def start_strong(self):
        self.out("'''")

    def end_strong(self):
        self.out("'''")

    def start_strikethrough(self):
        self.out("--(")

    def end_strikethrough(self):
        self.out(")--")

    def start_subscript(self):
        self.out(",,")

    def end_subscript(self):
        self.out(",,")

    def start_superscript(self):
        self.out("^")

    def end_superscript(self):
        self.out("^")

    def start_table(self):
        pass

    def end_table(self):
        pass

    def start_table_attrs(self):
        self.out("<")

    def end_table_attrs(self):
        self.out(">")

    def start_table_cell(self, attrs, leading, padding):
        self.out("||")

    def end_table_cell(self):
        pass

    def start_table_row(self, leading, padding):
        pass

    def end_table_row(self, trailing):
        self.out("||")
        self.out(trailing)

    def start_underline(self):
        self.out("__")

    def end_underline(self):
        self.out("__")

    def anchor(self, target):
        self.out("((%s))" % target)

    def break_(self):
        self.out("\n")

    def comment(self, comment, extra):
        self.out("##%s%s" % (comment, extra))

    def directive(self, directive, extra):
        self.out("#%s%s" % (directive, extra))

    def linebreak(self):
        self.out(r"\\")

    def link(self, target, nodes):
        self.out("[[%s" % target)
        for node in nodes:
            self.out("|")
            node.to_string(self)
        self.out("]]")

    def link_label(self, nodes):
        for node in nodes:
            node.to_string(self)

    def link_parameter(self, key_value):
        if len(key_value) == 1:
            self.out(key_value[0])
        else:
            self.out("=".join(key_value))

    def nbsp(self):
        self.out(r"\_")

    def rule(self, height):
        self.out("-" * (height + 4))

    def table_attrs(self, nodes):
        for node in nodes:
            node.to_string(self)

    def table_attr(self, name, value, concise, quote):
        if concise:
            if name == "bgcolor": self.out(value)
            elif name == "colspan": self.out("-%s" % value)
            elif name == "align" : self.out(value == "left" and "(" or value == "right" and ")" or ":")
            elif name == "rowspan": self.out("|%s" % value)
            elif name == "valign" : self.out(value == "top" and "^" or "v")
            elif name == "width" : self.out(value)
        else:
            self.out("%s%s" % (escape_text(name), value is not None and
                               "=%s%s%s" % (quote or '"', escape_attr(value), quote or '"') or ""))

    def text(self, s):
        self.out(s)

    def transclusion(self, target, nodes):
        self.out("{{%s" % target)
        for node in nodes:
            self.out("|")
            node.to_string(self)
        self.out("}}")

    def verbatim(self, text):
        self.out("<<<")
        self.out(text)
        self.out(">>>")

serialiser = MoinSerialiser

# vim: tabstop=4 expandtab shiftwidth=4
